<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sr_RS">
<context>
    <name>AddPluginDialog</name>
    <message>
        <location filename="../config/addplugindialog.ui" line="14"/>
        <source>Add Plugins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="22"/>
        <source>Search:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="98"/>
        <source>Add Widget</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="105"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.cpp" line="115"/>
        <source>(only one instance can run at a time)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigPanelDialog</name>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="31"/>
        <source>Configure Panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="39"/>
        <source>Placement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="43"/>
        <source>Styling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="47"/>
        <source>Widgets</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigPlacement</name>
    <message>
        <location filename="../config/configplacement.ui" line="20"/>
        <source>Configure placement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="44"/>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="68"/>
        <source>&lt;p&gt;Negative pixel value sets the panel length to that many pixels less than available screen space.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;E.g. &quot;Length&quot; set to -100px, screen size is 1000px, then real panel length will be 900 px.&lt;/i&gt;&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="81"/>
        <source>Size:</source>
        <translation>Величина:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="88"/>
        <source>Length:</source>
        <translation>Дужина:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="96"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="101"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="109"/>
        <location filename="../config/configplacement.ui" line="153"/>
        <source> px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="166"/>
        <source>Icon size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="173"/>
        <source>Rows:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="202"/>
        <source>Alignment &amp;&amp; position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="208"/>
        <source>Alignment:</source>
        <translation>Поравнање:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="219"/>
        <location filename="../config/configplacement.cpp" line="188"/>
        <source>Left</source>
        <translation>Лево</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="224"/>
        <location filename="../config/configplacement.cpp" line="189"/>
        <location filename="../config/configplacement.cpp" line="195"/>
        <source>Center</source>
        <translation>Центар</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="229"/>
        <location filename="../config/configplacement.cpp" line="190"/>
        <source>Right</source>
        <translation>Десно</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="237"/>
        <source>Position:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="250"/>
        <source>A&amp;uto-hide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="262"/>
        <location filename="../config/configplacement.ui" line="285"/>
        <source>Zero means no animation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="265"/>
        <source>Animation duration:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="288"/>
        <location filename="../config/configplacement.ui" line="314"/>
        <source> ms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="301"/>
        <location filename="../config/configplacement.ui" line="311"/>
        <source>Zero means no delay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="304"/>
        <source>Show with delay:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="327"/>
        <source>Visible thin margin for hidden panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="334"/>
        <source>Hide only on overlapping a window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="344"/>
        <source>Don&apos;t allow maximized windows go under the panel window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="347"/>
        <source>Reserve space on display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="154"/>
        <source>Top of desktop</source>
        <translation>врху површи</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="155"/>
        <source>Left of desktop</source>
        <translation>левој страни површи</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="156"/>
        <source>Right of desktop</source>
        <translation>десној страни површи</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="157"/>
        <source>Bottom of desktop</source>
        <translation>дну површи</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="166"/>
        <source>Top of desktop %1</source>
        <translation>врху површи %1</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="167"/>
        <source>Left of desktop %1</source>
        <translation>левој страни површи %1</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="168"/>
        <source>Right of desktop %1</source>
        <translation>десној страни површи %1</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="169"/>
        <source>Bottom of desktop %1</source>
        <translation>дну површи %1</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="194"/>
        <source>Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="196"/>
        <source>Bottom</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigPluginsWidget</name>
    <message>
        <location filename="../config/configpluginswidget.ui" line="14"/>
        <source>Configure Plugins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="84"/>
        <source>Note: changes made in this page cannot be reset.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="112"/>
        <source>Move up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="115"/>
        <location filename="../config/configpluginswidget.ui" line="129"/>
        <location filename="../config/configpluginswidget.ui" line="150"/>
        <location filename="../config/configpluginswidget.ui" line="164"/>
        <location filename="../config/configpluginswidget.ui" line="185"/>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="126"/>
        <source>Move down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="147"/>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="161"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="182"/>
        <source>Configure</source>
        <translation>Подеси</translation>
    </message>
</context>
<context>
    <name>ConfigStyling</name>
    <message>
        <location filename="../config/configstyling.ui" line="20"/>
        <source>Configure Styling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="44"/>
        <source>Custom styling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="65"/>
        <source>Font color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="105"/>
        <source>Background color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="144"/>
        <source>Background opacity:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="176"/>
        <source>&lt;small&gt;Compositing is required for panel transparency.&lt;/small&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="204"/>
        <source>Background image:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="256"/>
        <source>A partial workaround for widget styles that
cannot give a separate theme to the panel.

You might also want to disable:

LXQt Appearance Configuration →
Icons Theme →
Colorize icons based on widget style (palette)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="266"/>
        <source>Override icon &amp;theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="281"/>
        <source>Icon theme for panels:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configstyling.cpp" line="189"/>
        <location filename="../config/configstyling.cpp" line="205"/>
        <source>Pick color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configstyling.cpp" line="223"/>
        <source>Pick image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../config/configstyling.cpp" line="223"/>
        <source>Images (*.png *.gif *.jpg)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtPanel</name>
    <message>
        <location filename="../lxqtpanel.cpp" line="1177"/>
        <location filename="../lxqtpanel.cpp" line="1203"/>
        <source>Panel</source>
        <translation>Панел</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1206"/>
        <source>Configure Panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1211"/>
        <source>Manage Widgets</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1217"/>
        <source>Add New Panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1224"/>
        <source>Remove Panel</source>
        <comment>Menu Item</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1229"/>
        <source>Lock This Panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1385"/>
        <source>Remove Panel</source>
        <comment>Dialog Title</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1386"/>
        <source>Removing a panel can not be undone.
Do you want to remove this panel?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../plugin.cpp" line="438"/>
        <source>Configure &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plugin.cpp" line="443"/>
        <source>Move &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../plugin.cpp" line="451"/>
        <source>Remove &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../lxqtpanelapplication.cpp" line="95"/>
        <source>Use alternate configuration file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtpanelapplication.cpp" line="96"/>
        <source>Configuration file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
